@@ -38,6 +38,9 @@
 #define UNINSTALLED_PLUGINDIR "plugins/removable-devices"
 #define UNINSTALLED_SOURCE "nautilus-sendto-command.c"
 
+#define SOEXT           ("." G_MODULE_SUFFIX)
+#define SOEXT_LEN       (strlen (SOEXT))
+
 enum {
 	COLUMN_ICON,
 	COLUMN_DESCRIPTION,
@@ -76,7 +79,7 @@ struct _NS_ui {
 };
 
 static const GOptionEntry entries[] = {
-	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Movies to index", NULL },
+	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, "Files to send", "[FILES...]" },
 	{ NULL }
 };
 
@@ -446,7 +449,7 @@ set_model_for_options_combobox (NS_ui *ui)
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
 					COLUMN_ICON, pixbuf,
-					COLUMN_DESCRIPTION, _(p->info->description),
+					COLUMN_DESCRIPTION, dgettext(p->info->gettext_package, p->info->description),
 					-1);
 		if (last_used != NULL && !strcmp(last_used, p->info->id)) {
 			option = i;
@@ -502,6 +505,20 @@ pack_entry_changed_cb (GObject *object, GParamSpec *spec, NS_ui *ui)
 	gtk_widget_set_sensitive (ui->send_button, send_enabled);
 }
 
+static void
+update_button_image (GtkSettings *settings,
+		     GParamSpec *spec,
+		     GtkWidget *widget)
+{
+	gboolean show_images;
+
+	g_object_get (settings, "gtk-button-images", &show_images, NULL);
+	if (show_images == FALSE)
+		gtk_widget_hide (widget);
+	else
+		gtk_widget_show (widget);
+}
+
 static void
 nautilus_sendto_create_ui (void)
 {
@@ -510,6 +527,8 @@ nautilus_sendto_create_ui (void)
 	NS_ui *ui;
 	gboolean one_file = FALSE;
 	gboolean supports_dirs;
+	GtkSettings *settings;
+	GtkWidget *button_image;
 
 	app = gtk_builder_new ();
 	if (!gtk_builder_add_from_file (app, UIDIR "/" "nautilus-sendto.ui", &error))	{
@@ -532,6 +551,12 @@ nautilus_sendto_create_ui (void)
 	ui->status_label = GTK_WIDGET (gtk_builder_get_object (app, "status_label"));
 	ui->status_image = GTK_WIDGET (gtk_builder_get_object (app, "status_image"));
 
+	settings = gtk_settings_get_default ();
+	button_image = GTK_WIDGET (gtk_builder_get_object (app, "image1"));
+	g_signal_connect (G_OBJECT (settings), "notify::gtk-button-images",
+			  G_CALLBACK (update_button_image), button_image);
+	update_button_image (settings, NULL, button_image);
+
  	gtk_combo_box_set_active (GTK_COMBO_BOX(ui->pack_combobox), 
  		gconf_client_get_int(gconf_client, 
  				NAUTILUS_SENDTO_LAST_COMPRESS, NULL));
@@ -617,7 +642,7 @@ nautilus_sendto_plugin_dir_process (const char *plugindir)
 
 				p = g_new0(NstPlugin, 1);
 				module_path = g_module_build_path (plugindir, item);
-				p->module = g_module_open (module_path, G_MODULE_BIND_LAZY);
+				p->module = g_module_open (module_path, 0);
 			        if (!p->module) {
                 			g_warning ("error opening %s: %s", module_path, g_module_error ());
 					g_free (module_path);
@@ -679,20 +704,25 @@ nautilus_sendto_plugin_init (void)
 }
 
 static char *
-escape_ampersands (const char *url)
+escape_ampersands_and_commas (const char *url)
 {
 	int i;
 	char *str, *ptr;
 
-	/* Count the number of ampersands */
+	/* Count the number of ampersands & commas */
 	i = 0;
 	ptr = (char *) url;
 	while ((ptr = strchr (ptr, '&')) != NULL) {
 		i++;
 		ptr++;
 	}
+	ptr = (char *) url;
+	while ((ptr = strchr (ptr, ',')) != NULL) {
+		i++;
+		ptr++;
+	}
 
-	/* No ampersands ? */
+	/* No ampersands or commas ? */
 	if (i == 0)
 		return NULL;
 
@@ -700,12 +730,16 @@ escape_ampersands (const char *url)
 	str = g_malloc0 (strlen (url) - i + 3 * i + 1);
 	ptr = str;
 	for (i = 0; url[i] != '\0'; i++) {
-		if (url[i] != '&') {
-			*ptr++ = url[i];
-		} else {
+		if (url[i] == '&') {
 			*ptr++ = '%';
 			*ptr++ = '2';
 			*ptr++ = '6';
+		} else if (url[i] == ',') {
+			*ptr++ = '%';
+			*ptr++ = '2';
+			*ptr++ = 'C';
+		} else {
+			*ptr++ = url[i];
 		}
 	}
 
@@ -734,7 +768,7 @@ nautilus_sendto_init (void)
 
 		uri = g_filename_to_uri (filename, NULL, NULL);
 		g_free (filename);
-		escaped = escape_ampersands (uri);
+		escaped = escape_ampersands_and_commas (uri);
 
 		if (escaped == NULL) {
 			file_list = g_list_prepend (file_list, uri);
@@ -762,7 +796,7 @@ int main (int argc, char **argv)
 	textdomain (GETTEXT_PACKAGE);
 
 	g_thread_init (NULL);
-	context = g_option_context_new (_("Nautilus Sendto"));
+	context = g_option_context_new ("nautilus-sendto");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
